@@ -8,6 +8,12 @@ export OFFLINE=${OFFLINE:="no"}
 . ${BIN_DIR}/common.sh
 setup
 
+if [ ! -e "alembic/versions" ]; then
+  mkdir -p alembic/versions
+  alembic revision --autogenerate -m initial
+fi
+alembic upgrade head
+
 echo "Backend"
 echo "==============="
 uvicorn main:app --host 0.0.0.0 --port 5000 --reload
